@@ -1,5 +1,8 @@
 test_that("fire_exp_adjust() input checks work", {
   haz <- haz()
+
+  expect_warning(fire_exp_adjust(haz, tdist = 600),
+                 "'fire_exp_adjust' is deprecated")
   expect_error(fire_exp_adjust(2),
                "`hazard` must be a SpatRaster object")
   expect_error(fire_exp_adjust(haz),
@@ -16,12 +19,12 @@ test_that("fire_exp_adjust() input checks work", {
 
 test_that("fire_exp_adjust() returns correct object class", {
   haz <- haz()
-  expect_s4_class(fire_exp_adjust(haz, 350), "SpatRaster")
+  expect_s4_class(suppressWarnings(fire_exp_adjust(haz, 350)), "SpatRaster")
 })
 
 test_that("fire_exp_adjust() runs when input conditions are met", {
   haz <- haz()
   nb <- nb()
-  expect_no_error(fire_exp_adjust(haz, 350))
+  expect_no_error(suppressWarnings(fire_exp_adjust(haz, 350)))
   expect_no_error(fire_exp_adjust(haz, 350, nb))
 })
