@@ -1,6 +1,6 @@
 test_that("fire_exp_dir_plot() input checks work", {
   exp <- exposure()
-  v <- pol()
+  v <- polygon()
   pt <- pts(1)
 
   t_pt <- fire_exp_dir(exp, pt)
@@ -25,7 +25,7 @@ test_that("fire_exp_dir_plot() returns objects with correct class", {
 
 test_that("fire_exp_dir_plot() runs when input conditions are met", {
   exp <- exposure()
-  v <- pol()
+  v <- polygon()
   pt <- pts(1)
 
   t_pt <- fire_exp_dir(exp, pt)
